<?php

namespace Ems\Repository;

use Doctrine\ORM\EntityManager;

class OrganizacaoRepository {

    public function __construct(
        EntityManager $entityManager
    ) {
        $this->connection           = $entityManager->getConnection();
    }

    public function getOrganizacao(
        int $nrOrg,
        bool $throwException = false
    ): array {
        $sql = <<<SQL
            SELECT *
            FROM ORGANIZACAO
            WHERE NRORG = :P_NRORG
SQL;

        $params = [
            'P_NRORG' => $nrOrg
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $result = $std->fetch();

        if (!$result && $throwException) {
            $message = "Organização $nrOrg não encontrada!";
            throw new \Exception($message);
        }

        return $result;
    }

    public function getOrganizacaoByClientSecret(
        string $clientSecret,
        bool $throwException = false
    ): array {
        $sql = <<<SQL
            SELECT *
            FROM ORGANIZACAO
            WHERE CLIENT_SECRET = :P_CLIENT_SECRET
SQL;

        $params = [
            'P_CLIENT_SECRET' => $clientSecret
        ];

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $result = $std->fetch();

        if (!$result && $throwException) {
            $message = "Client secret $clientSecret não encontrado!";
            throw new \Exception($message);
        }

        return $result;
    }
}